ants.contrib.sklearn\_interface package
=======================================

Submodules
----------

ants.contrib.sklearn\_interface.sklearn\_registration module
------------------------------------------------------------

.. automodule:: ants.contrib.sklearn_interface.sklearn_registration
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: ants.contrib.sklearn_interface
   :members:
   :undoc-members:
   :show-inheritance:
